@@ -3,12 +3,14 @@
 // Primarily by Rod Smith, February 2009, but with a few functions
 // copied from other sources (see attributions below).
 
-/* This program is copyright (c) 2009-2013 by Roderick W. Smith. It is distributed
+/* This program is copyright (c) 2009-2018 by Roderick W. Smith. It is distributed
   under the terms of the GNU GPL version 2, as detailed in the COPYING file. */
 
 #define __STDC_LIMIT_MACROS
 #define __STDC_CONSTANT_MACROS
+#define __STDC_FORMAT_MACROS
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdint.h>
 #include <errno.h>
@@ -16,6 +18,8 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <string>
+#include <cctype>
+#include <algorithm>
 #include <iostream>
 #include <sstream>
 #include "support.h"
@@ -55,6 +59,7 @@ string ReadString(void) {
 string ReadString(void) {
    string inString;
 
+   cout << flush;
    getline(cin, inString);
    if (!cin.good())
       exit(5);
@@ -73,11 +78,11 @@ uint64_t GetNumber(uint64_t low, uint64_t high, uint64_t def, const string & pro
 
    if (low != high) { // bother only if low and high differ...
       do {
-         cout << prompt;
+         cout << prompt << flush;
          cin.getline(line, 255);
          if (!cin.good())
             exit(5);
-         num = sscanf(line, "%lld", &response);
+         num = sscanf(line, "%" PRIu64, &response);
          if (num == 1) { // user provided a response
             if ((response < low) || (response > high))
                cout << "Value out of range\n";
@@ -101,7 +106,7 @@ char GetYN(void) {
    do {
       if ( again ) { cout << "Your option? " ; }
       again = 1 ;
-      cout << "(Y/N): ";
+      cout << "(Y/N): " << flush;
       line = ReadString();
       response = toupper(line[0]);
    } while ((response != 'Y') && (response != 'N'));
@@ -357,3 +362,11 @@ void WinWarning(void) {
       exit(0);
    #endif
 } // WinWarning()
+
+// Returns the input string in lower case
+string ToLower(const string& input) {
+   string lower = input; // allocate correct size through copy
+
+   transform(input.begin(), input.end(), lower.begin(), ::tolower);
+   return lower;
+} // ToLower()
